import { Form } from "react-bootstrap";
import { Controller, useForm } from "react-hook-form";
import { useTranslation } from "react-i18next";
import validator from "validator";

type FormData = {
  id: number;
  boatTypename: string;
  seats: number;
  sport: string;
};

function EditBoatType(props: any) {

  const {
    control,
    handleSubmit,
    formState: { errors },
  } = useForm<FormData>({
    mode: "onBlur"
  });
  const { t } = useTranslation();

  const onSubmit = (data: FormData) => {
    try {
      /**
       * Logic to handle authentication. Should be separated into a service in another file.
       * await login(data);
       *
       *
       * navigate("/boatManager");
       */
    } catch (e) {
      alert("error");
    }
  };

  return (
    <Form onSubmit={handleSubmit(onSubmit)}>
      {props.id &&
        <Controller
          name="id"
          control={control}
          defaultValue= {props.id}
          render={({ field }) => (
            <div className="mb-2">
              <Form.Label >{t("boatTypeOverview.Id")}</Form.Label>
              <Form.Control disabled type="text" {...field} />
            </div>
          )}
          rules={{
            required: {
              value: true,
              message: t("boatTypeOverview.messages.required", {
                val: t("boatTypeOverview.Id"),
              }),
            }
          }}
        />
      }
      <Controller
        name="boatTypename"
        control={control}
        defaultValue={props.boatTypename}
        render={({ field }) => (
          <div className="mb-2">
            <Form.Label>{t("boatTypeOverview.Name")}</Form.Label>
            <Form.Control type="text" {...field} isInvalid={!!errors.boatTypename}/>
            <Form.Control.Feedback type="invalid">
              {errors.boatTypename?.message}
            </Form.Control.Feedback>
          </div>
        )}
        rules={{
          required: {
            value: true,
            message: t("boatTypeOverview.messages.required", {
              val: t("boatTypeOverview.Name"),
            }),
          },
          validate: (value: string) =>
          validator.isAlphanumeric(value) ||
          t("boatTypeOverview.messages.required").toString(),
        }}
      />
      <Controller
        name="seats"
        control={control}
        defaultValue={props.seats}
        render={({ field }) => (
          <div className="mb-2">
            <Form.Label>{t("boatTypeOverview.Seats")}</Form.Label>
            <Form.Control type="text" {...field} isInvalid={!!errors.boatTypename}/>
            <Form.Control.Feedback type="invalid">
              {errors.seats?.message}
            </Form.Control.Feedback>
          </div>
        )}
        rules={{
          required: {
            value: true,
            message: t("boatTypeOverview.messages.required", {
              val: t("boatTypeOverview.Seats"),
            }),
          }
        }}
      />
      <Controller
        name="sport"
        control={control}
        defaultValue={props.sport}
        render={({ field }) => (
          <div className="mb-2">
            <Form.Label>{t("boatTypeOverview.Sport")}</Form.Label>
            <Form.Select>
              <option>1</option>
            </Form.Select>
          </div>
        )}
        rules={{
          required: {
            value: true,
            message: t("boatTypeOverview.messages.required", {
              val: t("boatTypeOverview.Sport"),
            }),
          }
        }}
      />
    </Form>
  );
}

export default EditBoatType;
