import { Sequelize, DataTypes, Model, Optional } from "sequelize";

interface BoatHasSportAttributes {
  boatid: string;
  sportid: string;
}

export interface BoatHasSportAttributesInput
  extends Optional<BoatHasSportAttributes, "boatid"|"sportid"> {} // optional

class BoatHasSport
  extends Model<BoatHasSportAttributes, BoatHasSportAttributesInput>
  implements BoatHasSportAttributes
{
  declare boatid: string;
  declare sportid: string;

  declare readonly createdAt: Date;
  declare readonly updatedAt: Date;
}

export const initBoatHasSport = async (sequelizeConnection: Sequelize) => {
  BoatHasSport.init(
    {
      boatid: {
        type: DataTypes.UUID,
        allowNull: false,
        primaryKey: true,
        references: {
          model: "boat",
          key: "id",
        },
      },
      sportid: {
        type: DataTypes.UUID,
        allowNull: false,
        primaryKey: true,
        references: {
          model: "sport",
          key: "id",
        },
      },
    },

    {
      tableName: "boathassport",
      sequelize: sequelizeConnection,
    }
  );
};

export default BoatHasSport;
